@@ -347,11 +347,11 @@ class HanLPClient(object):
             language: The language of input text or tokens. ``None`` to use the default language on server.
 
         Returns:
-            A dictionary containing each keyphrase and its ranking score :math:`s`, :math:`s \in [0, 1]`.
+            A dictionary containing each keyword or keyphrase and its ranking score :math:`s`, :math:`s \in [0, 1]`.
         """
         assert text, 'Text has to be specified.'
-        scores = self._send_post_json(self._url + '/keyphrase_extraction', {
-            'text': text, 'language': language or self._language, 'topk': topk,
+        return self._send_post_json(self._url + '/keyphrase_extraction', {
+            'text': text,
+            'language': language or self._language,
+            'topk': topk,
         })
-        scores = dict(sorted(scores.items(), key=lambda x: (x[1], x[0]), reverse=True))
-        return scores
